@@ -4,6 +4,8 @@
 #ifndef QIOSTHEME_H
 #define QIOSTHEME_H
 
+#import <UIKit/UIKit.h>
+
 #include <QtCore/QHash>
 #include <QtGui/QPalette>
 #include <qpa/qplatformtheme.h>
@@ -21,22 +23,29 @@ public:
     const QPalette *palette(Palette type = SystemPalette) const override;
     QVariant themeHint(ThemeHint hint) const override;
 
-    Appearance appearance() const override;
+    Qt::ColorScheme colorScheme() const override;
+    void requestColorScheme(Qt::ColorScheme scheme) override;
+    Qt::ContrastPreference contrastPreference() const override;
 
+#if !defined(Q_OS_TVOS) && !defined(Q_OS_VISIONOS)
     QPlatformMenuItem* createPlatformMenuItem() const override;
     QPlatformMenu* createPlatformMenu() const override;
+#endif
 
     bool usePlatformNativeDialog(DialogType type) const override;
     QPlatformDialogHelper *createPlatformDialogHelper(DialogType type) const override;
 
     const QFont *font(Font type = SystemFont) const override;
+    QIconEngine *createIconEngine(const QString &iconName) const override;
 
     static const char *name;
 
     static void initializeSystemPalette();
+    static void applyTheme(UIWindow *window);
 
 private:
     static QPalette s_systemPalette;
+    static inline Qt::ColorScheme s_colorSchemeOverride = Qt::ColorScheme::Unknown;
     QMacNotificationObserver m_contentSizeCategoryObserver;
 };
 
